import time

from cloudcontrol.common.jobs import Job

class KillOldCliJob(Job):

    """ Typically an hidden job used to kill clients who are connected/idle
        since too much time.

    Mandatory items:
     * maxcon: maximum connection time in minutes
     * maxidle: maximum idle time in minutes

    Optional items:
     * delay: delay in secondes between two checks (default 1m)
    """

    DEFAULT_DELAY = 60

    def job(self, server, maxcon, maxidle, delay=DEFAULT_DELAY):
        self.state.title = 'Kill old clients (delay=%s)' % delay
        while True:
            self.checkpoint()
            for client in list(server.iterclients('cli')):
                if client.uptime > (maxcon * 60) or client.idle > (maxidle * 60):
                    server.kill(client.login)
                    self.logger.info('Disconnected %s because of its long time'
                                     ' or idle connection', client.login)
            time.sleep(delay)
